const ENV_OVERRIDE = `ROUTING_LOCAL_PROXY_BINARY`;

/**
 * Returns the path of the platform-specific routing-local-proxy binary, or
 * the value of the `ROUTING_LOCAL_PROXY_BINARY` environment variable, if set.
 *
 * Throws an error if there are no builds available for the current platform.
 */
const getBinaryPath = () => {
  let override = process.env[ENV_OVERRIDE];
  if (override) {
    console.log(
      `Using routing-local-proxy binary specified via environment variable ${ENV_OVERRIDE}: ${override}`,
    );
    return override;
  }

  const availableBinaries = ["darwin-arm64", "darwin-x64", "win32-x64", "linux-x64"];
  const currentPlatform = `${process.platform}-${process.arch}`;

  if (!availableBinaries.includes(currentPlatform)) {
    throw new Error(
      `There is no routing-local-proxy binary for ${currentPlatform}. routing-local-proxy only supports 64-bit x86 or Apple Silicon machines at the moment.`,
    );
  }

  return require(`@netlify/routing-local-proxy-${currentPlatform}`);
};

module.exports = { getBinaryPath };
